==> qtjambi-qt3drender-jre8-5.15.3-sources.jar: io/qt/qt3d/render/QTextureImageDataGenerator.java <==
package io.qt.qt3d.render;


/**
 * <p>Provides texture image data for QAbstractTextureImage</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qtextureimagedatagenerator.html">Qt3DRender::QTextureImageDataGenerator</a></p>
 */
public interface QTextureImageDataGenerator extends io.qt.QtObjectInterface, io.qt.qt3d.render.QAbstractFunctor
{
    /**
     * <p>Implementor class for interface {@link io.qt.qt3d.render.QTextureImageDataGenerator}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.qt3d.render.QTextureImageDataGenerator,
                io.qt.qt3d.render.QAbstractFunctor
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QTextureImageDataGenerator.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.qt3d.render.QTextureImageData get(){
                return get_native(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static io.qt.qt3d.render.QTextureImageData get_native(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean equals(io.qt.qt3d.render.QTextureImageDataGenerator other){
                java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
                return equals_native_cref_Qt3DRender_QTextureImageDataGenerator_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
            }
            private native static boolean equals_native_cref_Qt3DRender_QTextureImageDataGenerator_constfct(long __this__nativeId, long other);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QTextureImageDataGenerator instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtextureimagedatagenerator.html#operator-28-29">Qt3DRender::QTextureImageDataGenerator::operator()()</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.qt3d.render.QTextureImageData get();
        
        private native static io.qt.qt3d.render.QTextureImageData get_native(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtextureimagedatagenerator.html#operator-eq-eq">Qt3DRender::QTextureImageDataGenerator::operator==(Qt3DRender::QTextureImageDataGenerator)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean equals(io.qt.qt3d.render.QTextureImageDataGenerator other);
        
        private native static boolean equals_native_cref_Qt3DRender_QTextureImageDataGenerator_constfct(long __this__nativeId, long other);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        

        @Override
        @io.qt.QtUninvokable
        public boolean equals(Object other) {
            if (other instanceof io.qt.qt3d.render.QTextureImageDataGenerator) {
                return equals((io.qt.qt3d.render.QTextureImageDataGenerator) other);
            }

            return false;
        }

    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtextureimagedatagenerator.html#operator-28-29">Qt3DRender::QTextureImageDataGenerator::operator()()</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.qt3d.render.QTextureImageData get();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtextureimagedatagenerator.html#operator-eq-eq">Qt3DRender::QTextureImageDataGenerator::operator==(Qt3DRender::QTextureImageDataGenerator)const</a></p>
     */
    @io.qt.QtUninvokable
    public default boolean equals(io.qt.qt3d.render.QTextureImageDataGenerator other){
        return this==other;
    }
    
}

==> qtjambi-qt3drender-jre8-6.2-sources.jar: io/qt/qt3d/render/QTextureImageDataGenerator.java <==
package io.qt.qt3d.render;


/**
 * <p>Provides texture image data for QAbstractTextureImage</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qtextureimagedatagenerator.html">Qt3DRender::QTextureImageDataGenerator</a></p>
 */
public interface QTextureImageDataGenerator extends io.qt.QtObjectInterface, io.qt.qt3d.core.QAbstractFunctor
{
    /**
     * <p>Implementor class for interface {@link io.qt.qt3d.render.QTextureImageDataGenerator}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.qt3d.render.QTextureImageDataGenerator,
                io.qt.qt3d.core.QAbstractFunctor
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QTextureImageDataGenerator.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.qt3d.render.QTextureImageData get(){
                return get_native(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static io.qt.qt3d.render.QTextureImageData get_native(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean equals(io.qt.qt3d.render.QTextureImageDataGenerator other){
                java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
                return equals_native_cref_Qt3DRender_QTextureImageDataGenerator_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
            }
            private native static boolean equals_native_cref_Qt3DRender_QTextureImageDataGenerator_constfct(long __this__nativeId, long other);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QTextureImageDataGenerator instance);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtextureimagedatagenerator.html#operator-28-29">Qt3DRender::QTextureImageDataGenerator::</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.qt3d.render.QTextureImageData get();
        
        private native static io.qt.qt3d.render.QTextureImageData get_native(long __this__nativeId);
        
        /**
         * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtextureimagedatagenerator.html#operator-eq-eq">Qt3DRender::QTextureImageDataGenerator::</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean equals(io.qt.qt3d.render.QTextureImageDataGenerator other);
        
        private native static boolean equals_native_cref_Qt3DRender_QTextureImageDataGenerator_constfct(long __this__nativeId, long other);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        

        @Override
        @io.qt.QtUninvokable
        public boolean equals(Object other) {
            if (other instanceof io.qt.qt3d.render.QTextureImageDataGenerator) {
                return equals((io.qt.qt3d.render.QTextureImageDataGenerator) other);
            }

            return false;
        }

    }

    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtextureimagedatagenerator.html#operator-28-29">Qt3DRender::QTextureImageDataGenerator::operator()()</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.qt3d.render.QTextureImageData get();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtextureimagedatagenerator.html#operator-eq-eq">Qt3DRender::QTextureImageDataGenerator::operator==(Qt3DRender::QTextureImageDataGenerator)const</a></p>
     */
    @io.qt.QtUninvokable
    public default boolean equals(io.qt.qt3d.render.QTextureImageDataGenerator other){
        return this==other;
    }
    
}
